@@ -1,5 +1,5 @@
 /*
-    SPDX-FileCopyrightText: 2010-2021 Laurent Montel <montel@kde.org>
+    SPDX-FileCopyrightText: 2010-2022 Laurent Montel <montel@kde.org>
 
     SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -37,7 +37,7 @@ public Q_SLOTS:
 private:
     QVector<Config> m_configData;
     QString m_name;
-    KConfig *m_config = nullptr;
+    KConfig *const m_config;
     QString m_editName;
     bool m_editMode = false;
 };
