@@ -4,8 +4,7 @@
     SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#ifndef DYNAMICPAGE_H
-#define DYNAMICPAGE_H
+#pragma once
 
 #include "page.h"
 
@@ -23,4 +22,3 @@ private:
     QWidget *m_dynamicWidget = nullptr;
 };
 
-#endif
