@@ -6,10 +6,11 @@
 
 #include "resource.h"
 
-#include <AkonadiCore/ServerManager>
-#include <agentinstancecreatejob.h>
-#include <agentmanager.h>
-#include <agenttype.h>
+#include <Akonadi/AgentConfigurationDialog>
+#include <Akonadi/AgentInstanceCreateJob>
+#include <Akonadi/AgentManager>
+#include <Akonadi/AgentType>
+#include <Akonadi/ServerManager>
 
 #include "accountwizard_debug.h"
 #include <KLocalizedString>
@@ -17,6 +18,7 @@
 #include <QDBusInterface>
 #include <QDBusReply>
 #include <QMetaMethod>
+#include <QPointer>
 #include <QVariant>
 
 using namespace Akonadi;
@@ -35,7 +37,6 @@ static QVariant::Type argumentType(const QMetaObject *mo, const QString &method)
 
     if (m.methodSignature().isEmpty()) {
         qCWarning(ACCOUNTWIZARD_LOG) << "Did not find D-Bus method: " << method << " available methods are:";
-        const int numberOfMethod(mo->methodCount());
         for (int i = 0; i < numberOfMethod; ++i) {
             qCWarning(ACCOUNTWIZARD_LOG) << mo->method(i).methodSignature();
         }
@@ -53,7 +54,6 @@ static QVariant::Type argumentType(const QMetaObject *mo, const QString &method)
 Resource::Resource(const QString &type, QObject *parent)
     : SetupObject(parent)
     , m_typeIdentifier(type)
-    , m_editMode(false)
 {
 }
 
@@ -154,7 +154,9 @@ void Resource::instanceCreateResult(KJob *job)
 void Resource::edit()
 {
     if (m_instance.isValid()) {
-        m_instance.configure();
+        QPointer<Akonadi::AgentConfigurationDialog> dlg = new Akonadi::AgentConfigurationDialog(m_instance);
+        dlg->exec();
+        delete dlg;
     }
 }
 
