@@ -31,10 +31,10 @@ public Q_SLOTS:
     Q_SCRIPTABLE void setEditMode(const bool editMode);
 
 private:
-    int m_transportId;
+    int m_transportId = -1;
     QString m_name;
     QString m_host;
-    int m_port;
+    int m_port = -1;
     QString m_user;
     QString m_password;
     MailTransport::Transport::EnumEncryption::type m_encr;
@@ -42,6 +42,6 @@ private:
     QString m_encrStr;
     QString m_authStr;
 
-    bool m_editMode;
+    bool m_editMode = false;
 };
 
